@@ -18,17 +18,6 @@
 
 package jfractionlab;
 
-import javax.swing.JOptionPane;
-
-//import java.awt.Desktop;
-//import java.io.File;
-//import java.io.IOException;
-//import java.net.URI;
-//import java.net.URISyntaxException;
-//import java.net.URL;
-//
-//import javax.swing.JOptionPane;
-
 /**
  * It would be much nicer to use the standard desktop browser,
  * this should be possible with java.awt.Desktop
