@@ -32,8 +32,9 @@ import java.awt.event.ItemListener;
 import java.io.File;
 import java.io.FileInputStream;
 import java.io.ObjectInputStream;
+import java.util.Enumeration;
 import java.util.Locale;
-
+import java.util.Properties;
 import java.util.Random;
 
 import javax.swing.JButton;
@@ -51,10 +52,10 @@ import javax.swing.border.EmptyBorder;
 import javax.swing.border.EtchedBorder;
 import javax.swing.border.TitledBorder;
 
-
 import jfractionlab.displays.PointDisplay;
 import jfractionlab.exerciseDialogs.ClickNumerator;
 import jfractionlab.exerciseDialogs.CompareFractions;
+import jfractionlab.exerciseDialogs.DecimalToFraction;
 import jfractionlab.exerciseDialogs.DivideFractionsByFractions;
 import jfractionlab.exerciseDialogs.DivideFractionsByNumbers;
 import jfractionlab.exerciseDialogs.DivideNumbersByFractions;
@@ -74,16 +75,13 @@ import jfractionlab.jflDialogs.WorkSheetDialog;
 import jfractionlab.logtable.LogTable;
 
 
-
 //TODO JFractionLab
 
-//begriffe fuer aufgaben (zettel) und übungen (am computer)
+// formulare als jar mitliefern und vom programm ins homeverzeichnis kopieren lassen
 
 //neuer aufgabentyp: vergleichen durch gleichnamig machen?
-//Link zur Hilfe (oder mindestens hineis auf hilfekapitel) in fehlermeldung "kein LO-Kontakt"
 
 //Hilfe: ****************************
-//configureLO_de.html url einsetzen
 //CompareFractions: hilfe schreiben und implementieren
 //FractionToDecimal Hilfekapitel schreiben und hier verlinken!
 //hilfe besser internationalisieren mit cmssimple?? "offline"-cms ohne datenbank??
@@ -93,11 +91,11 @@ import jfractionlab.logtable.LogTable;
 //arbeitsblätter mit verschiedenen aufgabentypen ermoeglichen, dialog mit allen auswahlmöglichkeiten schreiben
 
 //Release: ******************************
-//testen (achte auf ConfigureLO unter windows!!)
-//uebersetzen
-//pakete machen
 //document the code with javadoc
 
+//FIXME jfl arbeitsblätter unechte brueche 90/24 = 3 18/24
+//FIXME jfl arbeitsblätter multiplizieren wertebereich nur bis 20
+
 public class JFractionLab extends JFrame implements ActionListener, ItemListener{
 	public static final long serialVersionUID = 54L;
 	public static final String jep_fontface="<font face='Avalon,Wide Latin'>";
@@ -112,12 +110,14 @@ public class JFractionLab extends JFrame implements ActionListener, ItemListener
 		private JMenuItem jmiEnglish = new JMenuItem("");
 		private JMenuItem jmiItalian = new JMenuItem("");
 		private JMenuItem jmiPortuguese = new JMenuItem("");
-//		private JMenuItem jmiPolish = new JMenuItem("");
+		private JMenuItem jmiGreek = new JMenuItem("");
+		private JMenuItem jmiPolish = new JMenuItem("");
 	private JMenu jmWorkSheet = new JMenu("");
 		private JMenuItem jmiWorkSheetExtending = new JMenuItem("");
 		private JMenuItem jmiWorkSheetReducing = new JMenuItem("");
 		private JMenuItem jmiWorkSheetImproperFractions = new JMenuItem("");
 		private JMenuItem jmiWorkSheetMixedNumbers = new JMenuItem("");
+		private JMenuItem jmiWorksheetFractionToDecimal = new JMenuItem("");
 		private JMenuItem jmiWorkSheetAddition = new JMenuItem("");
 		private JMenuItem jmiWorkSheetSubtraction = new JMenuItem("");
 		private JMenuItem jmiWorkSheetMultiplication = new JMenuItem("");
@@ -145,6 +145,10 @@ public class JFractionLab extends JFrame implements ActionListener, ItemListener
 	private PointDisplay dsp_mixedNumbers = new PointDisplay(true);
 	private JButton btn_fractionToDecimal;
 	private PointDisplay dsp_fractionToDecimal = new PointDisplay(true);
+	
+	private JButton btn_decimalToFraction;
+	private PointDisplay dsp_decimalToFraction = new PointDisplay(true);
+	
 	private TitledBorder brd_bottom;
 	private JButton btn_addFractions;
 	private PointDisplay dsp_addFractions = new PointDisplay(true);
@@ -176,6 +180,7 @@ public class JFractionLab extends JFrame implements ActionListener, ItemListener
 	public int points_unechteBrueche = 0;
 	public int points_gemischteZahlen = 0;
 	public int points_fractionToDecimal = 0;
+	public int points_decimalToFraction = 0;
 	public int points_addFractions = 0;
 	public int points_subtractFractions = 0;
 	public int points_multiplyFractions = 0;
@@ -201,6 +206,7 @@ public class JFractionLab extends JFrame implements ActionListener, ItemListener
 				new JFractionLab();
 			}//run
 		});//invokeLater
+//		JOptionPane.showMessageDialog(null,"Hallo Hendrik");
 	}
 	
 	public JFractionLab() throws HeadlessException {
@@ -236,14 +242,18 @@ public class JFractionLab extends JFrame implements ActionListener, ItemListener
 		jmiItalian.addActionListener(this);
 		jmLanguage.add(jmiItalian);
 
-//		jmiPolish.setText(lang.Messages.getString("polish"));
-//		jmiPolish.addActionListener(this);
-//		jmLanguage.add(jmiPolish);
+		jmiPolish.setText(lang.Messages.getString("polish"));
+		jmiPolish.addActionListener(this);
+		jmLanguage.add(jmiPolish);
 		
 		jmiPortuguese.setText(lang.Messages.getString("portuguese"));
 		jmiPortuguese.addActionListener(this);
 		jmLanguage.add(jmiPortuguese);
 		
+		jmiGreek.setText(lang.Messages.getString("greek"));
+		jmiGreek.addActionListener(this);
+		jmLanguage.add(jmiGreek);
+		
 		jmWorkSheet.setText(lang.Messages.getString("worksheets"));
 		
 		jmiWorkSheetExtending.addActionListener(this);
@@ -262,6 +272,10 @@ public class JFractionLab extends JFrame implements ActionListener, ItemListener
 		jmiWorkSheetMixedNumbers.setText(lang.Messages.getString("mixed_numbers"));
 		jmWorkSheet.add(jmiWorkSheetMixedNumbers);
 
+		jmiWorksheetFractionToDecimal.addActionListener(this);
+		jmiWorksheetFractionToDecimal.setText(lang.Messages.getString("fraction_to_decimal"));
+		jmWorkSheet.add(jmiWorksheetFractionToDecimal);
+		
 		jmiWorkSheetAddition.addActionListener(this);
 		jmiWorkSheetAddition.setText(lang.Messages.getString("add_fractions"));
 		jmWorkSheet.add(jmiWorkSheetAddition);
@@ -327,7 +341,8 @@ public class JFractionLab extends JFrame implements ActionListener, ItemListener
 			TableLayout.FILL,//4
 			TableLayout.FILL,//5
 			TableLayout.FILL,//6
-			TableLayout.FILL//7
+			TableLayout.FILL,//7
+			TableLayout.FILL//8
 		}};
 		double sizes_unten[][] = {{
 			// Spalten
@@ -350,6 +365,7 @@ public class JFractionLab extends JFrame implements ActionListener, ItemListener
 			btn_clickNumerator.addActionListener(this);
 		pn_oben.add(btn_clickNumerator, "0,0,1,0");
 		pn_oben.add(dsp_clickNumerator, "2,0");
+		
 			btn_nameFraction = new JButton("2. "+lang.Messages.getString("name_fractions"));
 			btn_nameFraction.addActionListener(this);
 		pn_oben.add(btn_nameFraction, "0,1,1,1");
@@ -378,30 +394,34 @@ public class JFractionLab extends JFrame implements ActionListener, ItemListener
 			btn_fractionToDecimal.addActionListener(this);
 		pn_oben.add(btn_fractionToDecimal, "0,7,1,7");
 		pn_oben.add(dsp_fractionToDecimal, "2,7");
+			btn_decimalToFraction = new JButton("9. "+ lang.Messages.getString("decimal_to_fraction"));
+			btn_decimalToFraction.addActionListener(this);
+		pn_oben.add(btn_decimalToFraction, "0,8,1,8");
+		pn_oben.add(dsp_decimalToFraction, "2,8");
 		brd_top = new TitledBorder(new EtchedBorder(), lang.Messages.getString("learn_fractions"));
 		pn_oben.setBorder(brd_top);
 		cp.add(pn_oben, "0,0");
-			btn_addFractions = new JButton("9. "+lang.Messages.getString("add_fractions"));
+			btn_addFractions = new JButton("10. "+lang.Messages.getString("add_fractions"));
 			btn_addFractions.addActionListener(this);
 		pn_unten.add(btn_addFractions, "0,0,1,0");
 		pn_unten.add(dsp_addFractions, "2,0");
-			btn_subtractFractions = new JButton("10. "+lang.Messages.getString("minus_fractions"));
+			btn_subtractFractions = new JButton("11. "+lang.Messages.getString("minus_fractions"));
 			btn_subtractFractions.addActionListener(this);
 		pn_unten.add(btn_subtractFractions, "0,1,1,1");
 		pn_unten.add(dsp_subtractFractions, "2,1");
-			btn_multiplyFractions = new JButton("11. "+lang.Messages.getString("multiply_fractions"));
+			btn_multiplyFractions = new JButton("12. "+lang.Messages.getString("multiply_fractions"));
 			btn_multiplyFractions.addActionListener(this);
 		pn_unten.add(btn_multiplyFractions, "0,2,1,2");
 		pn_unten.add(dsp_multiplyFractions, "2,2");
-			btn_divideFractionsByNumbers = new JButton("12. "+lang.Messages.getString("div_fr_by_nb"));
+			btn_divideFractionsByNumbers = new JButton("13. "+lang.Messages.getString("div_fr_by_nb"));
 			btn_divideFractionsByNumbers.addActionListener(this);
 		pn_unten.add(btn_divideFractionsByNumbers, "0,3,1,3");
 		pn_unten.add(dsp_divideFractionsByNumbers, "2,3");
-			btn_divideNumbersByFractions = new JButton("13. "+lang.Messages.getString("div_nb_by_fr"));
+			btn_divideNumbersByFractions = new JButton("14. "+lang.Messages.getString("div_nb_by_fr"));
 			btn_divideNumbersByFractions.addActionListener(this);
 		pn_unten.add(btn_divideNumbersByFractions, "0,4,1,4");
 		pn_unten.add(dsp_divideNumbersByFractions, "2,4");
-			btn_divideFractionsByFractions = new JButton("14. "+lang.Messages.getString("div_fr_by_fr"));
+			btn_divideFractionsByFractions = new JButton("15. "+lang.Messages.getString("div_fr_by_fr"));
 			btn_divideFractionsByFractions.addActionListener(this);
 		pn_unten.add(btn_divideFractionsByFractions, "0,5,1,5");
 		pn_unten.add(dsp_divideFractionsByFractions, "2,5");
@@ -425,12 +445,16 @@ public class JFractionLab extends JFrame implements ActionListener, ItemListener
 		setResizable(true);
 		//JFrame.setDefaultLookAndFeelDecorated(true);
 		try{
-			UIManager.setLookAndFeel("javax.swing.plaf.metal.MetalLookAndFeel");
-			//UIManager.setLookAndFeel("javax.swing.plaf.metal.NimbusLookAndFeel");
-			//UIManager.setLookAndFeel("com.sun.java.swing.plaf.motif.MotifLookAndFeel");
-			//UIManager.setLookAndFeel("com.sun.java.swing.plaf.windows.WindowsLookAndFeel");
-			//UIManager.setLookAndFeel(UIManager.getCrossPlatformLookAndFeelClassName());
-			//UIManager.setLookAndFeel( UIManager.getSystemLookAndFeelClassName() );
+			UIManager.setLookAndFeel( UIManager.getSystemLookAndFeelClassName() );
+			//see http://www.pushing-pixels.org/2008/07/13/swing-applications-and-mac-os-x-menu-bar.html
+			if(System.getProperty("os.name").toLowerCase().contains("mac")){
+				UIManager.put("MenuBarUI",UIManager.getSystemLookAndFeelClassName());
+				UIManager.put("MenuUI",UIManager.getSystemLookAndFeelClassName());
+				UIManager.put("MenuItemUI",UIManager.getSystemLookAndFeelClassName());
+				UIManager.put("CheckBoxMenuItemUI",UIManager.getSystemLookAndFeelClassName());
+				UIManager.put("RadioButtonMenuItemUI",UIManager.getSystemLookAndFeelClassName());
+				UIManager.put("PopupMenuUI",UIManager.getSystemLookAndFeelClassName());
+			}
 		}catch(Exception exc){
 			exc.printStackTrace();
 			System.out.println("UIManager Problem");
@@ -452,11 +476,14 @@ public class JFractionLab extends JFrame implements ActionListener, ItemListener
 			//gudrungeorges@gmail.com
 			+ lang.Messages.getString("english_translators")+"</li><li>"
 			//Loupiotebec@aol.com
+			//mirco.bergamini@yahoo.it
 			+ lang.Messages.getString("italian_translators")+"</li><li>"
 			//khemis@bol.com.br
 			+ lang.Messages.getString("portuguese_translators")+"</li><li>"
-			//cazaria@gmx.net
-	//		+ lang.Messages.getString("polish_translators")+"</li><li>"
+			//passalis@csd.auth.gr
+			+ lang.Messages.getString("greek_translators")+"</li><li>"
+			+ lang.Messages.getString("polish_translators")+"</li><li>"
+			//rafalsurynt@gmail.com
 			//jredrejo@edu.juntaextremadura.net>
 			+ lang.Messages.getString("debian_package_maintainer")+"</li><li>"
 			+ lang.Messages.getString("icon_designer")+"</li><li>"
@@ -465,6 +492,17 @@ public class JFractionLab extends JFrame implements ActionListener, ItemListener
 		;//String
 		
 		
+		//some properties
+//		System.out.println("liste der properties = ");
+//		Properties sysprops   = System.getProperties();
+//		Enumeration<?> propnames = sysprops.propertyNames();
+//		while (propnames.hasMoreElements()) {
+//			String propname = (String)propnames.nextElement();
+//			System.out.println(
+//					propname + "=" + System.getProperty(propname)
+//			);
+//		}
+		System.out.println("CLASSPATH = "+System.getProperty("java.class.path"));
 	}//makeGUI
 	
 	/**
@@ -497,6 +535,9 @@ public class JFractionLab extends JFrame implements ActionListener, ItemListener
 		}else if (prog == "fractiontodecimal"){
 			points_fractionToDecimal = p;
 			dsp_fractionToDecimal.setText(String.valueOf(p));
+		}else if (prog == "decimalToFraction"){
+			points_decimalToFraction = p;
+			dsp_decimalToFraction.setText(String.valueOf(p));
 		}else if (prog == "addFractions"){
 			points_addFractions = p;
 			dsp_addFractions.setText(String.valueOf(p));
@@ -533,12 +574,14 @@ public class JFractionLab extends JFrame implements ActionListener, ItemListener
 		jmiEnglish.setText(lang.Messages.getString("english"));
 		jmiItalian.setText(lang.Messages.getString("italian"));
 		jmiPortuguese.setText(lang.Messages.getString("portuguese"));
-//		jmiPolish.setText(lang.Messages.getString("polish"));
+		jmiGreek.setText(lang.Messages.getString("greek"));
+		jmiPolish.setText(lang.Messages.getString("polish"));
 		jmWorkSheet.setText(lang.Messages.getString("worksheets"));
 		jmiWorkSheetExtending.setText(lang.Messages.getString("extend_fractions"));
 		jmiWorkSheetReducing.setText(lang.Messages.getString("reduce_fractions"));
 		jmiWorkSheetImproperFractions.setText(lang.Messages.getString("improper_fracs"));
 		jmiWorkSheetMixedNumbers.setText(lang.Messages.getString("mixed_numbers"));
+		jmiWorksheetFractionToDecimal.setText(lang.Messages.getString("fraction_to_decimal"));
 		jmiWorkSheetAddition.setText(lang.Messages.getString("add_fractions"));
 		jmiWorkSheetSubtraction.setText(lang.Messages.getString("minus_fractions"));
 		jmiWorkSheetMultiplication.setText(lang.Messages.getString("multiply_fractions"));
@@ -559,7 +602,8 @@ public class JFractionLab extends JFrame implements ActionListener, ItemListener
 		btn_improperFracions.setText("6. "+lang.Messages.getString("improper_fracs"));
 		btn_mixedNumbers.setText("7. "+lang.Messages.getString("mixed_numbers"));
 		btn_fractionToDecimal.setText("8. "+lang.Messages.getString("fraction_to_decimal"));
-
+		btn_decimalToFraction.setText("9. " + lang.Messages.getString("decimal_to_fraction"));
+		
 		brd_bottom.setTitle(lang.Messages.getString("calculate_fractions"));
 		btn_addFractions.setText("9. "+lang.Messages.getString("add_fractions"));
 		btn_subtractFractions.setText("10. "+lang.Messages.getString("minus_fractions"));
@@ -615,6 +659,8 @@ public class JFractionLab extends JFrame implements ActionListener, ItemListener
         		new MixedNumbers(this,location_x, location_y, size_x, size_y+200);
         	}else if (obj == btn_fractionToDecimal){
         		new FractionToDecimal(this,location_x, location_y, size_x, size_y+200);
+        	}else if (obj == btn_decimalToFraction){
+        		new DecimalToFraction(this,location_x, location_y, size_x, size_y+200);
         	}else if (obj == btn_addFractions){
         		new PlusAndMinus(this, "+", location_x, location_y, size_x + 100, size_y + 60);
         	}else if (obj == btn_subtractFractions){
@@ -637,6 +683,7 @@ public class JFractionLab extends JFrame implements ActionListener, ItemListener
         			points_unechteBrueche,
         			points_gemischteZahlen,
         			points_fractionToDecimal,
+        			points_decimalToFraction,
         			points_addFractions,
         			points_subtractFractions,
         			points_multiplyFractions,
@@ -653,6 +700,7 @@ public class JFractionLab extends JFrame implements ActionListener, ItemListener
 	    			setPoints(0, "unechteBrueche");
 	    			setPoints(0, "gemischteZahlen");
 	    			setPoints(0, "fractiontodecimal");
+	    			setPoints(0, "decimalToFraction");
 	    			setPoints(0, "addFractions");
 	    			setPoints(0, "subtractFractions");
 	    			setPoints(0, "multiplyFractions");
@@ -684,6 +732,7 @@ public class JFractionLab extends JFrame implements ActionListener, ItemListener
 						lang.Messages.getString("improper_fracs"),
 						lang.Messages.getString("mixed_numbers"),
 						lang.Messages.getString("fraction_to_decimal"),
+						lang.Messages.getString("decimal_to_fraction"),
 						lang.Messages.getString("add_fractions"),
 						lang.Messages.getString("minus_fractions"),
 						lang.Messages.getString("multiply_fractions"),
@@ -746,40 +795,46 @@ public class JFractionLab extends JFrame implements ActionListener, ItemListener
 							data[i][9] = String.valueOf(sl.getPtsFtD());
 						}
 						
-						if(sl.getPtsPL()==0){
+						if(sl.getPtsDtF()==0){
 							data[i][10] = " ";
 						}else{
-							data[i][10] = String.valueOf(sl.getPtsPL());
+							data[i][10] = String.valueOf(sl.getPtsDtF());
+						}
+						
+						if(sl.getPtsPL()==0){
+							data[i][11] = " ";
+						}else{
+							data[i][11] = String.valueOf(sl.getPtsPL());
 						}
 						
 						if(sl.getPtsMIN()==0){
-							data[i][11] = " ";
+							data[i][12] = " ";
 						}else{
-							data[i][11] = String.valueOf(sl.getPtsMIN());
+							data[i][12] = String.valueOf(sl.getPtsMIN());
 						}
 						
 						if(sl.getPtsMF()==0){
-							data[i][12] = " ";
+							data[i][13] = " ";
 						}else{
-							data[i][12] = String.valueOf(sl.getPtsMF());
+							data[i][13] = String.valueOf(sl.getPtsMF());
 						}
 						
 						if(sl.getPtsDFN()==0){
-							data[i][13] = " ";
+							data[i][14] = " ";
 						}else{
-							data[i][13] = String.valueOf(sl.getPtsDFN());
+							data[i][14] = String.valueOf(sl.getPtsDFN());
 						}
 						
 						if(sl.getPtsDNF()==0){
-							data[i][14] = " ";
+							data[i][15] = " ";
 						}else{
-							data[i][14] = String.valueOf(sl.getPtsDNF());
+							data[i][15] = String.valueOf(sl.getPtsDNF());
 						}
 						
 						if(sl.getPtsDFF()==0){
-							data[i][15] = " ";
+							data[i][16] = " ";
 						}else{
-							data[i][15] = String.valueOf(sl.getPtsDFF());
+							data[i][16] = String.valueOf(sl.getPtsDFF());
 						}
 						
 					}catch( Exception ex ) {
@@ -810,11 +865,14 @@ public class JFractionLab extends JFrame implements ActionListener, ItemListener
 		}else if (obj == jmiPortuguese){
 			lang.Messages.setLocale(new Locale("pt"));
 			refreshCaption();
+		}else if(obj == jmiGreek){
+			lang.Messages.setLocale(new Locale("gr"));
+			refreshCaption();
+		}
+		else if (obj == jmiPolish){
+			lang.Messages.setLocale(new Locale("pl"));
+			refreshCaption();
 		}
-//		else if (obj == jmiPolish){
-//			lang.Messages.setLocale(new Locale("pl"));
-//			refreshCaption();
-//		}
 		else if(obj == jmiWorkSheetExtending){
 			new WorkSheetDialog(
 					ExerciseGenerator.EXTEND_FRACTIONS,
@@ -842,10 +900,21 @@ public class JFractionLab extends JFrame implements ActionListener, ItemListener
 					lang.Messages.getString("full_numbers"),
 					lang.Messages.getString("fractions")
 			);
+		}else if(obj == jmiWorksheetFractionToDecimal){
+			new WorkSheetDialog(
+					ExerciseGenerator.FRACTIONS_TO_DECIMAL,
+					lang.Messages.getString("fraction_to_decimal")
+			);
 		}else if(obj == jmiWorkSheetAddition){
-			new WorkSheetDialog(ExerciseGenerator.ADD_FRACTIONS, lang.Messages.getString("add_fractions"));
+			new WorkSheetDialog(
+					ExerciseGenerator.ADD_FRACTIONS,
+					lang.Messages.getString("add_fractions")
+			);
 		}else if(obj == jmiWorkSheetSubtraction){
-			new WorkSheetDialog(ExerciseGenerator.SUBTRACT_FRACTIONS, lang.Messages.getString("minus_fractions"));
+			new WorkSheetDialog(
+					ExerciseGenerator.SUBTRACT_FRACTIONS,
+					lang.Messages.getString("minus_fractions")
+			);
 		}else if(obj == jmiWorkSheetMultiplication){
 			new WorkSheetDialog(
 					ExerciseGenerator.MULTIPLY_FRACTIONS,
