@@ -36,6 +36,7 @@ public class ResultOfGame implements Serializable{
 		private int ptsIF;
 		private int ptsMN;
 		private int ptsFtD;
+		private int ptsDtF;
 		private int ptsPL;
 		private int ptsMIN;
 		private int ptsMF;
@@ -69,9 +70,9 @@ public class ResultOfGame implements Serializable{
 		 * @param ptsDFF
 		 * @param p_14
 		 */
-		public ResultOfGame(String sn,int ptsCN,int ptsNF,int ptsCF,int ptsEF,int ptsRF,int ptsIF,int ptsMN,int ptsFtD,
+		public ResultOfGame(String sn,int ptsCN,int ptsNF,int ptsCF,int ptsEF,int ptsRF,int ptsIF,int ptsMN,int ptsFtD, int ptsDtF,
 				int ptsPL,int ptsMIN,int ptsMF,int ptsDFN,int ptsDNF,int ptsDFF){
-			setAll(sn,ptsCN,ptsNF,ptsCF,ptsEF,ptsRF,ptsIF,ptsMN,ptsFtD,ptsPL,ptsMIN,ptsMF,ptsDFN,ptsDNF,ptsDFF);
+			setAll(sn,ptsCN,ptsNF,ptsCF,ptsEF,ptsRF,ptsIF,ptsMN,ptsFtD,ptsDtF,ptsPL,ptsMIN,ptsMF,ptsDFN,ptsDNF,ptsDFF);
 		}
 
 		/**
@@ -92,7 +93,7 @@ public class ResultOfGame implements Serializable{
 		 * @param ptsDFF
 		 * @param p_14
 		 */
-		public void setAll(String sn,int ptsCN,int ptsNF,int ptsCF,int ptsEF,int ptsRF,int ptsIF,int ptsMN,int ptsFtD,int ptsPL,int ptsMIN,int ptsMF,int ptsDFN,int ptsDNF,int ptsDFF){
+		public void setAll(String sn,int ptsCN,int ptsNF,int ptsCF,int ptsEF,int ptsRF,int ptsIF,int ptsMN,int ptsFtD,int ptsDtF,int ptsPL,int ptsMIN,int ptsMF,int ptsDFN,int ptsDNF,int ptsDFF){
 			this.playersName = sn;
 			this.ptsCN = ptsCN;
 			this.ptsNF = ptsNF;
@@ -102,6 +103,7 @@ public class ResultOfGame implements Serializable{
 			this.ptsIF = ptsIF;
 			this.ptsMN = ptsMN;
 			this.ptsFtD = ptsFtD;
+			this.ptsDtF = ptsDtF;
 			this.ptsPL = ptsPL;
 			this.ptsMIN = ptsMIN;
 			this.ptsMF = ptsMF;
@@ -153,6 +155,7 @@ public class ResultOfGame implements Serializable{
 		public int getPtsIF(){return ptsIF;}
 		public int getPtsMN(){return ptsMN;}
 		public int getPtsFtD(){return ptsFtD;}
+		public int getPtsDtF(){return ptsDtF;}
 		public int getPtsPL(){return ptsPL;}
 		public int getPtsMIN(){return ptsMIN;}
 		public int getPtsMF(){return ptsMF;}
@@ -160,6 +163,7 @@ public class ResultOfGame implements Serializable{
 		public int getPtsDNF(){return ptsDNF;}
 		public int getPtsDFF(){return ptsDFF;}
 		
+		
 		/**
 		 * 
 		 *
@@ -179,12 +183,13 @@ public class ResultOfGame implements Serializable{
 			System.out.println("points 06             :  "+ String.valueOf(ptsIF));
 			System.out.println("points 07             :  "+ String.valueOf(ptsMN));
 			System.out.println("points 08             :  "+ String.valueOf(ptsFtD));
-			System.out.println("points 08             :  "+ String.valueOf(ptsPL));
-			System.out.println("points 09             :  "+ String.valueOf(ptsMIN));
-			System.out.println("points 10             :  "+ String.valueOf(ptsMF));
-			System.out.println("points 11             :  "+ String.valueOf(ptsDFN));
-			System.out.println("points 12             :  "+ String.valueOf(ptsDNF));
-			System.out.println("points 13             :  "+ String.valueOf(ptsDFF));
+			System.out.println("points 09             :  "+ String.valueOf(ptsDtF));
+			System.out.println("points 10             :  "+ String.valueOf(ptsPL));
+			System.out.println("points 11             :  "+ String.valueOf(ptsMIN));
+			System.out.println("points 12             :  "+ String.valueOf(ptsMF));
+			System.out.println("points 13             :  "+ String.valueOf(ptsDFN));
+			System.out.println("points 14             :  "+ String.valueOf(ptsDNF));
+			System.out.println("points 15             :  "+ String.valueOf(ptsDFF));
 			System.out.println("######################");
 			System.out.println("");
 		}
