@@ -28,13 +28,11 @@ import java.awt.KeyboardFocusManager;
 import java.awt.event.ActionEvent;
 import java.awt.event.ActionListener;
 import java.awt.event.KeyEvent;
-import java.awt.event.KeyListener;
 
 import javax.swing.JButton;
 import javax.swing.JLabel;
 
 import jfractionlab.FractionMaker;
-import jfractionlab.GreatestCommonDivisor;
 import jfractionlab.JFractionLab;
 import jfractionlab.displays.FractionAsCircle;
 import jfractionlab.displays.FractionLine;
@@ -97,7 +95,6 @@ public class CompareFractions extends ExerciseDialog implements ActionListener{
 		jmOptions.add(rb_invisible);
 		jmb.add(jmOptions);
 		jmiHelp.addActionListener(this);
-		//FIXME => hilfe implementieren
 		jmb.add(jmHelp);
 		setJMenuBar(jmb);
 		
@@ -167,7 +164,7 @@ public class CompareFractions extends ExerciseDialog implements ActionListener{
 			lb_info.setText(lang.Messages.getString("use_the_mouse"));
 		content.add(lb_info, "0,7,7,7");
 		makeProblem();
-		String[] ar_howto = {"howto_click_bigger_smaller","howto_type_bigger_smaller","howto_option_invisible"};
+		String[] ar_howto = {"howto_click_bigger_smaller","howto_option_invisible"};
 		new UsabilityDialog(ar_howto);//new UsabilityDialog
 		
 	
