@@ -75,6 +75,7 @@ public abstract class ExerciseDialog extends JDialog {
 	JFractionLab owner;
 	public boolean bl_with_reducing = false;
 	boolean bl_randomProblem = true;
+	boolean smallNumbers = true;
 	public boolean bl_wannaReduceQuestion_AnswerIsYes = false;
 	public boolean bl_WannaFindBestCommonDenominator_AnswerIsYes = false;
 	
@@ -162,7 +163,6 @@ public abstract class ExerciseDialog extends JDialog {
 	}//readInputNumber
 
 	public Double readInputDouble(MyJTextField jtf){
-//		hier weiter
 		Double ret;
 		try{
 			String str= jtf.getText();
@@ -179,7 +179,6 @@ public abstract class ExerciseDialog extends JDialog {
 		return ret;
 	}//readInputDouble
 	
-	
 	abstract protected void nextProblem();
 	abstract protected void makeProblem();
 	
