@@ -31,16 +31,16 @@ import java.awt.event.KeyListener;
 import javax.swing.JButton;
 import javax.swing.JLabel;
 
-import jfractionlab.ConfManager;
 import jfractionlab.FractionMaker;
 import jfractionlab.HelpStarter;
 import jfractionlab.JFractionLab;
 import jfractionlab.MyJTextField;
 import jfractionlab.displays.FractionAsCircle;
 import jfractionlab.displays.FractionLine;
+import jfractionlab.exerciseGenerator.ExerciseGenerator;
 import jfractionlab.jflDialogs.UsabilityDialog;
-import jfractionlab.jflDialogs.WorkSheetDialogExtending;
-import jfractionlab.jflDialogs.WorkSheetDialogMultiplication;
+import jfractionlab.jflDialogs.WorkSheetDialog;
+
 
 
 
@@ -202,7 +202,12 @@ public class ExtendFraction extends ExerciseDialog implements ActionListener, Ke
 		}else if (obj == btn_end){
 			close_it();
 		}else if(obj == jmiCreateWorkSheet){
-			new WorkSheetDialogExtending();
+			new WorkSheetDialog(
+					ExerciseGenerator.EXTEND_FRACTIONS,
+					lang.Messages.getString("extend_fractions"),
+					lang.Messages.getString("fractions"),
+					lang.Messages.getString("factors")
+			);
 		}else if(obj == jmiHelp){
 			new HelpStarter(
 					lang.Messages.getLocale().toString(),
