@@ -37,7 +37,9 @@ import jfractionlab.JFractionLab;
 import jfractionlab.MyJTextField;
 import jfractionlab.displays.FractionAsRectangle;
 import jfractionlab.displays.FractionLine;
+import jfractionlab.exerciseGenerator.ExerciseGenerator;
 import jfractionlab.jflDialogs.UsabilityDialog;
+import jfractionlab.jflDialogs.WorkSheetDialog;
 
 public class FractionToDecimal extends ExerciseDialog implements ActionListener, KeyListener{
 	static final long serialVersionUID = JFractionLab.serialVersionUID;
@@ -77,6 +79,9 @@ public class FractionToDecimal extends ExerciseDialog implements ActionListener,
 		rb_custom.addActionListener(this);
 		jmOptions.add(rb_custom);
 		jmb.add(jmOptions);
+		jmiCreateWorkSheet.addActionListener(this);
+		jmWorkSheet.add(jmiCreateWorkSheet);
+		jmb.add(jmWorkSheet);
 		jmiHelp.addActionListener(this);
 		jmb.add(jmHelp);
 		setJMenuBar(jmb);
@@ -183,7 +188,7 @@ public class FractionToDecimal extends ExerciseDialog implements ActionListener,
 	 */
 	protected void makeProblem(){
 		//System.out.println("makeProblem");
-		fraction.mkDecimalFraction();
+		fraction.mkDecimalFraction(true);
 		numerator_1 = fraction.getNumerator_1();
 		denominator_1 = fraction.getDenominator_1();
 		denominator_2 = calculateDenominator2(denominator_1);
@@ -197,11 +202,15 @@ public class FractionToDecimal extends ExerciseDialog implements ActionListener,
 	}
 	
 	private int calculateDenominator2(int dn1){
-		if(10%denominator_1==0){
-			return 10;
-		}else{
-			return 100;
-		}
+			System.out.println("dn 1 = "+dn1);
+			if(dn1 == 0){
+				System.out.println("mist dn1 ist 0!!!!");
+				return 10;
+			}else if(10%dn1==0){
+				return 10;
+			}else{
+				return 100;
+			}
 	}
 	/**
 	 * 
@@ -247,6 +256,11 @@ public class FractionToDecimal extends ExerciseDialog implements ActionListener,
 			//it should switch to "custom-mode"
 			bl_randomProblem = false;
 			nextProblem();
+		}else if(obj == jmiCreateWorkSheet){
+			new WorkSheetDialog(
+					ExerciseGenerator.FRACTIONS_TO_DECIMAL,
+					lang.Messages.getString("fraction_to_decimal")
+			);
 		}
 	}//actionPerformed
 	
