@@ -32,17 +32,15 @@ import java.awt.event.KeyListener;
 import javax.swing.JButton;
 import javax.swing.JLabel;
 
-import jfractionlab.ConfManager;
 import jfractionlab.FractionMaker;
 import jfractionlab.HelpStarter;
 import jfractionlab.JFractionLab;
 import jfractionlab.MyJTextField;
 import jfractionlab.displays.FractionAsCircle;
 import jfractionlab.displays.FractionLine;
+import jfractionlab.exerciseGenerator.ExerciseGenerator;
 import jfractionlab.jflDialogs.UsabilityDialog;
-import jfractionlab.jflDialogs.WorkSheetDialogImproperFractions;
-
-
+import jfractionlab.jflDialogs.WorkSheetDialog;
 
 
 /**
@@ -359,7 +357,11 @@ static final long serialVersionUID = JFractionLab.serialVersionUID;
 			bl_randomProblem = false;
 			nextProblem();
 		}else if(obj == jmiCreateWorkSheet){
-			new WorkSheetDialogImproperFractions();
+			new WorkSheetDialog(
+					ExerciseGenerator.IMPROPER_FRACTIONS,
+					lang.Messages.getString("improper_fracs"),
+					lang.Messages.getString("fractions")
+			);
 		}else if(obj == jmiHelp){
 			new HelpStarter(
 					lang.Messages.getLocale().toString(),
