@@ -84,7 +84,7 @@ public class MultiplyFractions extends ExerciseDialog implements ActionListener,
 	private int numerator2;
 	private int denominator1;
 	private int denominator2;
-	private boolean smallNumbers = true;
+
 	
 	private boolean bl_problem_was_solved_with_reducing = false;
 	/**
@@ -266,23 +266,23 @@ public class MultiplyFractions extends ExerciseDialog implements ActionListener,
 		//denominator1 = 9;
 		//numerator2 = 5;
 		//denominator2 = 8;
-		//erster Bruch
+		//first fraction
 		tf_numerator1.setText(String.valueOf(numerator1));
 		tf_denominator1.setText(String.valueOf(denominator1));
 		pizza1.drawPizzaAsRectangle(numerator1, denominator1, Color.yellow, false,true);
-		//bla
-		//zweiter Bruch
+
+		//second fraction
 		tf_numerator2.setText(String.valueOf(numerator2));
 		tf_denominator2.setText(String.valueOf(denominator2));
 		pizza2.drawPizzaAsRectangle(numerator2, denominator2, Color.yellow, true,true);
-		//Rechnung:
+		//calculation
 		tf_calculation_numerator1.setText(String.valueOf(numerator1));
 		tf_calculation_denominator1.setText(String.valueOf(denominator1));
 		calculation_pizza.drawPizzaAsRectangle(numerator1, denominator1, numerator2, denominator2, Color.yellow,true);
-		//zweiter Bruch
+		//second fraction of calculation
 		tf_calculation_numerator2.setText(String.valueOf(numerator2));
 		tf_calculation_denominator2.setText(String.valueOf(denominator2));
-		//Krzbar?
+		//isReducable?
 		if(bl_with_reducing){
 			checkReducability();
 		}else{
@@ -314,7 +314,7 @@ public class MultiplyFractions extends ExerciseDialog implements ActionListener,
 	 * 
 	 *
 	 */
- 	private void checkReducability(){
+	private void checkReducability(){
 		if(JFractionLab.greatestCommonDivisor(Integer.parseInt(tf_calculation_numerator1.getText()),Integer.parseInt(tf_calculation_denominator1.getText())) != 1){
 			initReductionProcess(1,1);
 		}else if(JFractionLab.greatestCommonDivisor(Integer.parseInt(tf_calculation_numerator1.getText()),Integer.parseInt(tf_calculation_denominator2.getText())) != 1){
