@@ -37,16 +37,16 @@ import java.awt.event.KeyListener;
 import javax.swing.JButton;
 import javax.swing.JLabel;
 
-import jfractionlab.ConfManager;
 import jfractionlab.FractionMaker;
 import jfractionlab.HelpStarter;
 import jfractionlab.JFractionLab;
 import jfractionlab.MyJTextField;
 import jfractionlab.displays.FractionAsCircle;
 import jfractionlab.displays.FractionLine;
+import jfractionlab.exerciseGenerator.ExerciseGenerator;
 import jfractionlab.jflDialogs.ReduceHintDialog;
 import jfractionlab.jflDialogs.UsabilityDialog;
-import jfractionlab.jflDialogs.WorkSheetDialogReducing;
+import jfractionlab.jflDialogs.WorkSheetDialog;
 
 
 public class ReduceFraction extends ExerciseDialog implements ActionListener, KeyListener{
@@ -199,6 +199,7 @@ public class ReduceFraction extends ExerciseDialog implements ActionListener, Ke
 	
 	protected void nextProblem(){
 		clearTextFields();
+		tipIsSet = false;
 		if (bl_randomProblem == true){
 			makeProblem();
 		}else{
@@ -235,7 +236,12 @@ public class ReduceFraction extends ExerciseDialog implements ActionListener, Ke
 			bl_randomProblem = false;
 			nextProblem();
 		}else if(obj == jmiCreateWorkSheet){
-			new WorkSheetDialogReducing();
+			new WorkSheetDialog(
+					ExerciseGenerator.REDUCE_FRACTIONS,
+					lang.Messages.getString("reduce_fractions"),
+					lang.Messages.getString("fractions"),
+					lang.Messages.getString("factors")
+			);
 		}else if(obj == jmiHelp){
 			new HelpStarter(
 					lang.Messages.getLocale().toString(),
@@ -293,7 +299,7 @@ public class ReduceFraction extends ExerciseDialog implements ActionListener, Ke
 						||
 						denominator_1 % (numerator_1/num2)!=0
 				){
-					lb_info.setText("reduce_by_a_common_denominator");
+					lb_info.setText(lang.Messages.getString("reduce_by_a_common_denominator"));
 					tf_numerator_2.setText("");
 				}else{
 					tf_numerator_2.setEditable(false);
