@@ -53,6 +53,7 @@ public class LogSaverDialog extends JDialog implements ActionListener{
 		private int ptsIF;
 		private int ptsMN;
 		private int ptsFtD;
+		private int ptsDtF;
 		private int ptsPL;
 		private int ptsMIN;
 		private int ptsMF;
@@ -68,7 +69,7 @@ public class LogSaverDialog extends JDialog implements ActionListener{
 		public boolean isSavedSuccessfully = false;
 	public LogSaverDialog(
 			int ptsCN,int ptsNF,int ptsCF,int ptsEF,int ptsRF,int ptsIF,
-			int ptsMN, int ptsFtD,
+			int ptsMN, int ptsFtD,int ptsDtF,
 			int ptsPL,int ptsMIN,int ptsMF,int ptsDFN,int ptsDNF,int ptsDFF
 		){ //neues Spiel machen
 		setTitle(lang.Messages.getString("save_results"));
@@ -87,6 +88,7 @@ public class LogSaverDialog extends JDialog implements ActionListener{
 		this.ptsIF = ptsIF;
 		this.ptsMN = ptsMN;
 		this.ptsFtD = ptsFtD;
+		this.ptsDtF= ptsDtF;
 		this.ptsPL = ptsPL;
 		this.ptsMIN = ptsMIN;
 		this.ptsMF = ptsMF;
@@ -130,7 +132,7 @@ public class LogSaverDialog extends JDialog implements ActionListener{
 		if(!tf_name.getText().equals("")){
 			playersName = tf_name.getText();
 			ResultOfGame sl = new ResultOfGame(
-					playersName,ptsCN,ptsNF,ptsCF,ptsEF,ptsRF,ptsIF,ptsMN, ptsFtD,
+					playersName,ptsCN,ptsNF,ptsCF,ptsEF,ptsRF,ptsIF,ptsMN, ptsFtD,ptsDtF,
 					ptsPL,ptsMIN,ptsMF,ptsDFN,ptsDNF,ptsDFF);
 			String zeitstempel = sl.getTimeStamp();
 			JFileChooser fc = new JFileChooser();
